;; In load-path, after this directory should come
;; certain of its subdirectories.  Here we specify them.
(normal-top-level-add-to-load-path '("toolbar" "textmodes" "progmodes" "play" "obsolete" "net" "mail" "language" "international" "gnus" "eshell" "emulation" "emacs-lisp" "calendar" ))
